<?php
// $Id: weblinks_checker.admin.inc,v 1.1.2.1 2009/05/10 21:11:13 nancyw Exp $

/**
 * @file
 * Settings form.
 */

/**
 * Validity check settings.
 */
function weblinks_checker_settings() {
  drupal_add_js(drupal_get_path('module', 'weblinks_checker') .'/weblinks_checker.js');
  drupal_add_css(drupal_get_path('module', 'weblinks') .'/weblinks.css');

  $form = array();
  $yesno = array(1 => t('Yes'), 0 => t('No'));

  include(drupal_get_path('module', 'weblinks') .'/weblinks_errors.inc');

  $form['weblinks_allow_dupes'] = array(
    '#type' => 'radios',
    '#title' => t('Allow duplicate URLs'),
    '#default_value' => variable_get('weblinks_allow_dupes', 0),
    '#options' => array(1 => t('yes'), 0 => t('no'), 2 => t('warn')),
    '#description' => t('This check is performed at link creation time. Most users will not want to allow duplicate URLs.'),
    '#prefix' => '<div class="weblinks-radios">',
    '#suffix' => '</div><div class="clear-block"></div>',
    );

  $form['weblinks_validate_check'] = array(
    '#type' => 'radios',
    '#options' => $yesno,
    '#prefix' => '<div class="weblinks-radios">',
    '#suffix' => '</div>',
    '#title' => t('Check if link is valid when entered'),
    '#default_value' => (int) variable_get('weblinks_validate_check', FALSE),
    '#description' => t('If enabled, the module will attempt to use the URL to contact the site when the link is created or updated. If the link returns any error, the add/update will fail.'),
    );

  $form['weblinks_checker_enabled'] = array(
    '#type' => 'radios',
    '#options' => $yesno,
    '#prefix' => '<div class="weblinks-radios">',
    '#suffix' => '</div>',
    '#title' => t('Enable link validity checker?'),
    '#description' => t('Do you want to check the links on a schedule?'),
    '#default_value' => (int) variable_get('weblinks_checker_enabled', FALSE),
    );

  $form['weblinks_checker_limit'] = array(
    '#type' => 'textfield',
    '#title' => t('Links to include'),
    '#description' => t('This sets the number of links to be checked on each Cron run. If there are too many, the Cron run may time out.'),
    '#size' => 2,
    '#default_value' => variable_get('weblinks_checker_limit', 5),
    '#prefix' => '<div class="weblinks_checker_hide">',
    );

  $form['weblinks_checker_detail_log'] = array(
    '#type' => 'radios',
    '#options' => $yesno,
    '#prefix' => '<div class="weblinks-radios">',
    '#suffix' => '</div>',
    '#title' => t('Show URLs checked in log'),
    '#description' => t('If this is selected, all URLs that are checked will be logged.'),
    '#default_value' => (int) variable_get('weblinks_checker_detail_log', FALSE),
    );

  $form['weblinks_checker_unpublish'] = array(
    '#type' => 'radios',
    '#options' => $yesno,
    '#prefix' => '<div class="weblinks-radios">',
    '#suffix' => '</div>',
    '#title' => t('Unpublish link on second error'),
    '#description' => t('If a previous error has been detected, do you want the link unpublished?'),
    '#default_value' => (int) variable_get('weblinks_checker_unpublish', FALSE),
    );

  $form['weblinks_checker_redirect'] = array(
    '#type' => 'radios',
    '#options' => $yesno,
    '#prefix' => '<div class="weblinks-radios">',
    '#suffix' => '</div>',
    '#title' => t('Update link on permanent redirect'),
    '#description' => t('If a link is marked as a permanent redirect ("301"), do you want the link updated?'),
    '#default_value' => (int) variable_get('weblinks_checker_redirect', FALSE),
    );

  $interval = array(0, 15*60, 30*60, 60*60, 2*60*60, 3*60*60, 4*60*60, 6*60*60, 12*60*60, 24*60*60, 2*24*60*60, 3*24*60*60, 7*24*60*60, 14*24*60*60, 28*24*60*60);
  $form['weblinks_checker_interval'] = array(
    '#type' => 'select',
    '#options' => drupal_map_assoc($interval, 'format_interval'),
    '#title' => t('Cron interval'),
    '#description' => t("This sets the frequency of checking. If you run Cron frequently, you may wish to set this higher than your Cron frequency so that you don't overload the linked site. The check will be run at the next scheduled Cron run after this interval expires. An interval of 0 means every cron run."),
    '#size' => count($interval) / 2,
    '#default_value' => variable_get('weblinks_checker_interval', 24*60*60),
    );

  $ignore_deflt = variable_get('weblinks_checker_ignore', array());
  if (!$ignore_deflt) {
    $ignore_deflt = weblinks_error_codes();
    foreach ($ignore_deflt as $code => $text) {
      if (substr($code, 0, 1) == '2' || substr($code, 0, 1) == '1') {
        $ignore_deflt[$code] = $code;
      }
      else {
        $ignore_deflt[$code] = FALSE;
      }
    }
  }

  $form['ignore'] = array(
    '#type' => 'fieldset',
    '#title' => t('Ignore error codes'),
    '#description' => t('The validity checker will treat all the selected codes as OK.
      For more information, see <a href="!url" target="_blank">this page</a>.',
      array('!url' => url('http://www.w3.org/Protocols/rfc2616/rfc2616-sec10.html', array('external' => TRUE)))),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    );

  $form['ignore']['weblinks_checker_ignore'] = array(
    '#type' => 'checkboxes',
    '#options' => weblinks_error_codes(),
    '#default_value' => $ignore_deflt,
    '#prefix' => '<div class="weblinks-checkboxes">',
    '#suffix' => '</div></div><!-- /weblinks_checker_hide --><br />',
    );

  // The following are for user deletion.
  $form['rescue'] = array(
    '#type' => 'fieldset',
    '#title' => t("User Deletion Action"),
    '#description' => t('This section determines what you want to do with links submitted by a user who is subsequently deleted.'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    );

/*  $form['rescue']['weblinks_user_rescue'] = array(
    '#type' => 'radios',
    '#options' => array('delete' => t('Delete the links'), 'move' => t('Move them to another user')),
    '#title' => t("Rescue a deleted user's links?"),
    '#description' => t('What should we do with the links submitted by a user who is subsequently deleted?'),
    '#default_value' => variable_get('weblinks_user_rescue', 'move'),
    '#prefix' => '<div class="weblinks-radios">',
    '#suffix' => '</div>',
    ); /* */
  $form['rescue']['weblinks_user_rescue'] = array(
    '#type' => 'value',
    '#value' => 'move',   /* there is a core bug that prevents 'delete' for now */
    );

  $result = db_query("SELECT uid, name FROM {users}");
  $rescue_users = array();
  while ($row = db_fetch_array($result)) {
    $rescue_users[$row['uid']] = $row['name'];
  }
  $rescue_users[0] = variable_get('anonymous', t('Anonymous'));

  $form['rescue']['weblinks_rescue_move'] = array(
    '#type' => 'select',
    '#options' => $rescue_users,
    '#title' => t('Move to user'),
    '#description' => t('Select the user to whom the links will be moved.'),
    '#default_value' => variable_get('weblinks_rescue_move', 1),
    '#prefix' => '<div class="weblinks-move-user-list">',
    '#suffix' => '</div>',
    );

  $form['rescue']['weblinks_rescue_unpub'] = array(
    '#type' => 'radios',
    '#options' => array(0 => t('Unpublished'), 1 => t('Published')),
    '#title' => t('Status after the move'),
    '#description' => t('When moving the link to the other user, should the link be published or unpublished?'),
    '#default_value' => (int) variable_get('weblinks_rescue_unpub', 0),
    '#prefix' => '<div class="weblinks-radios">',
    '#suffix' => '</div><br />',
    );

  return system_settings_form($form);
}
